'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

/* 
 * @author Arsen Borovinskiy, 2020
 */

var SendFilePlayer = React.createClass({
  displayName: 'SendFilePlayer',

  // props.node
  // props.chromeColor
  // props.textColor
  // props.viewMode
  // props.height (string like 100% or 400px)
  // props.isKiosk

  mixins: [ElisStyleMixin, ElisPlayerMixin, TranslateMixin],

  getInitialState: function getInitialState() {

    var height = this.getViewPortHeight();

    var topPanelHeight = 50;

    var iframeHeight = height - topPanelHeight;

    return {
      xhr: new XMLHttpRequest(),
      topPanelMargin: topPanelHeight,
      width: this.props.width != null ? this.props.width : window.innerWidth,
      height: height,
      iframeHeight: iframeHeight,
      isKiosk: false,
      isSupportFullScreen: false,
      isFullScreenEnabled: false,
      deleteDate: null, // time for delete node
      message: null // human readable string when files will deleting
    };
  },

  getDefaultProps: function getDefaultProps() {

    return {
      isApp: false,
      isDebug: false,
      viewMode: 'full'
    };
  },

  componentDidMount: function componentDidMount() {
    var self = this;
    window.addEventListener("resize", this.handlerOnResize);
    this.handlerOnResize();
    this.componentWillReceiveProps(this.props);
    this.playLog('init');
    //ElisPlayLog.plusDataCount(1);
    this.playLog('start');
    var onPlayLogSended = function onPlayLogSended() {
      self.loadInfo();
    };
    if (navigator.onLine !== false) {
      // if we ofline, can not success send play log and must try use cache
      ElisPlayLog.send('xhr', onPlayLogSended);
    } else {
      onPlayLogSended();
    }
    this.setState({ isSupportFullScreen: this.isSupportFullScreen() });
  },

  componentWillUnMount: function componentWillUnMount() {
    window.removeEventListener("resize", this.handlerOnResize);
    this.playLog('reset');
  },

  componentWillReceiveProps: function componentWillReceiveProps(newProps) {
    if (newProps.node != null && newProps.node.nid != this.props.node.nid) {
      this.loadInfo();
    }
  },

  handlerOnResize: function handlerOnResize(e) {
    var height = window.innerHeight;
    var iframeHeight = this.state.iframeHeight;

    if (height == NaN) {
      height = document.getElementsByTagName("html")[0].clientHeight;
      iframeHeight = height - this.state.topPanelHeight - 4;
    }

    this.setState({ width: window.innerWidth, height: height, iframeHeight: iframeHeight });
  },

  // load info about zip structure
  loadInfo: function loadInfo() {
    var xhr = this.state.xhr;
    xhr.abort();
    var self = this;
    var url = this.props.baseUrl + "/node/" + this.props.node.nid + "/sendfile/info";
    xhr.open("GET", url, true);
    xhr.onreadystatechange = function (e) {
      if (xhr.readyState == 4) {
        if (xhr.status == 200) {
          ElisPlayLog.addEvent({ type: 'infoLoaded' });
          var data = JSON.parse(xhr.responseText);
          if (data.error == false) {
            var deleteDate = null;
            var message = null;
            if (typeof data.info.timeBeforeDeleteSec === 'number') {
              deleteDate = new Date();
              deleteDate.setTime(data.info.deleteTimestamp * 1000);
              message = deleteDate.toLocaleString(navigator.language);
            }
            self.setState({ info: data.info, message: message, deleteDate: deleteDate }); // info.files have stat from zip files info.indexFileName have local filename or false if index file is not exists
          }
        }
      }
    };
    xhr.send();
  },

  getTranslate: function getTranslate(str, lang) {
    return this.getInnerTranslation(str, lang);
  },

  translation: function translation() {
    return {
      'en': {
        'Share': 'Share',
        'Download': 'Download',
        'Downloads': 'Downloads',
        'Statistics': 'Statistics',
        'User': 'User',
        'Fullscreen': 'Fullscreen',
        'FilesWillBeDeletedOn': 'Files will be deleted on',
        'B': 'B',
        'KB': 'KB',
        'MB': 'MB',
        'GB': 'GB'
      },
      'ru': {
        'Share': 'Поделиться',
        'Download': 'Скачать',
        'Downloads': 'Скачивание',
        'Statistics': 'Статистика',
        'User': 'Пользователь',
        'Fullscreen': 'Полноэкранный режим',
        'FilesWillBeDeletedOn': 'Файлы будут удалены',
        'B': 'Б',
        'KB': 'КБ',
        'MB': 'МБ',
        'GB': 'ГБ'
      }
    };
  },

  getUrlForFile: function getUrlForFile(file) {
    return this.props.baseUrl + '/node/' + this.props.node.nid + "/sendfile/download/" + file.fid + "/" + file.filename;
  },


  // open file from one file
  downloadFile: function downloadFile(file) {
    var fileUrl = this.getUrlForFile(file);
    var isBinary = true;
    var res = window.open(fileUrl, 'download');
    if (res) {
      ElisPlayLog.plusDataCount(1);
      ElisPlayLog.addEvent({ type: 'download', value: fileUrl + '' });
    }
  },

  toggleFullScreen: function toggleFullScreen() {
    // it is toggle fullscreen todo: move to PlayerCommons
    var result = false;
    if (this.isSupportFullScreen()) {
      if (false == this.isFullScreenEnabled()) {
        result = this.requestFullScreen(ReactDOM.findDOMNode(this));
        if (result != false) {
          this.setState({ isFullScreenEnabled: true });
          return;
        }
      } else {
        this.cancelFullScreen();
        this.setState({ isFullScreenEnabled: false });
        return;
      }
    }
    // if not fullscreen
    window.open(this.props.baseUrl + "/node/" + this.props.node.nid + '/embed');
  },

  isImage: function isImage(file) {
    var fileName = (typeof file === 'undefined' ? 'undefined' : _typeof(file)) === 'object' ? file.filename : file;
    return fileName.search(/\.((jpg)|(jpeg)|(jfif)|(svg)|(png)|(webp))$/) > -1 ? true : false;
  },

  getHumanFilesize: function getHumanFilesize(file) {
    var size = parseInt(file.filesize);
    var suffix = 'B';
    if (file.filesize != null) {
      if (size > 1024 * 1024 * 1024) {
        size = size / 1024 / 1024 / 1024;
        suffix = 'GB';
      } else if (size > 1024 * 1024) {
        size = size / 1024 / 1024;
        suffix = 'MB';
      } else if (size > 1024) {
        size = size / 1024;
        suffix = 'KB';
      }
    }
    if (typeof size === 'number') {
      size = size.toFixed(1);
    }
    return size + ' ' + this.t(suffix);
  },

  handleOnDownloadClick: function handleOnDownloadClick() {
    if (this.state.info.isAllowUnprotectedDownload && !!this.state.info.sourceDownloadUrl) {
      var url = this.state.info.sourceDownloadUrl;
      window.open(url);
      ElisPlayLog.addEvent({ type: 'download', value: url });
    }
  },

  render: function render() {

    var self = this;

    if (this.state == null) {
      return React.createElement(
        'div',
        null,
        React.createElement(BusyIndicator, null)
      );
    }

    if (this.props == null || this.props.node === null || this.props.node.nid === null || this.props.baseUrl === null) {
      return React.createElement(
        'div',
        null,
        'loading web resource'
      );
    }

    var playerBodyWrapperStyle;
    if (this.props.viewMode == "embed") {
      playerBodyWrapperStyle = { marginTop: this.state.topPanelMargin, overflow: "auto" };
    } else {
      playerBodyWrapperStyle = { marginTop: this.state.topPanelMargin, height: "100%", maxHeight: this.getViewPortHeight() - this.state.topPanelMargin, overflow: "auto" };
    }

    var iframeHeight = this.state.height - this.state.topPanelHeight; // now not used

    var navbarHeight = "50px";
    var bodyHeight = "calc(100% - " + navbarHeight + ")";
    playerBodyWrapperStyle = { marginTop: 0, marginBottom: 0, height: bodyHeight, maxHeight: "calc(100vh - " + navbarHeight + ")" };

    var iconStyle = { color: this.props.textColor };

    // var sandbox = 'sandbox="allow-same-origin allow-scripts allow-popups allow-forms"';

    return React.createElement(
      'div',
      { className: 'player-wrapper', style: { background: "#fff", height: "100%", display: "flex", flexDirection: "column" } },
      React.createElement(
        'div',
        { className: 'elis-catalog-title', style: { boxShadow: "0 2px 2px 0 rgba(0,0,0,.14), 0 3px 1px -2px rgba(0,0,0,.2), 0 1px 5px 0 rgba(0,0,0,.12)", zIndex: 1 } },
        React.createElement(
          'div',
          { className: 'elis-navbar elis-top-attached-navbar elis-top-player-navbar', style: { backgroundColor: this.props.chromeColor, height: navbarHeight, position: "static", marginTop: 0, marginBottom: 0, overflowY: "hidden" }, onDoubleClick: this.handlerOnDoubleClick },
          React.createElement(
            'ul',
            { className: 'nav elis-navbar-nav' },
            this.props.onClose != null ? React.createElement(
              'li',
              { onClick: this.handlerOnClickUpButton },
              React.createElement(
                'a',
                { className: 'withripple', 'aria-label': this.t('Back') },
                React.createElement('i', { className: 'mdi-navigation-arrow-back' })
              )
            ) : false,
            this.state.isSupportFullScreen && !this.props.isKiosk ? React.createElement(
              'li',
              { onClick: this.toggleFullScreen },
              React.createElement(
                'a',
                { className: 'withripple', 'aria-label': this.t('Fullscreen') },
                React.createElement('i', { className: 'mdi-action-settings-overscan', style: iconStyle })
              )
            ) : false,
            this.state.info != null && !this.props.isKiosk ? React.createElement(
              'li',
              { onClick: this.handleOnDownloadClick, style: { display: 'none' } },
              React.createElement(
                'a',
                { className: 'withripple', 'aria-label': this.t('Fullscreen') },
                React.createElement('i', { className: 'mdi-file-cloud-download', style: iconStyle })
              )
            ) : false
          )
        )
      ),
      React.createElement(
        'div',
        { className: 'player-body-wrapper', style: playerBodyWrapperStyle },
        React.createElement(
          'div',
          { className: 'player-pages-wrapper', style: { height: "100%", background: this.getChromeColor(), color: this.getTextColor() } },
          this.state.info != null && this.state.info.files != null ? React.createElement(
            'div',
            { style: { height: "100%" } },
            this.state.message != null ? React.createElement(
              'div',
              { style: { padding: '1em', margin: 0 } },
              this.t('FilesWillBeDeletedOn'),
              ' ',
              this.state.message
            ) : React.createElement('div', null),
            React.createElement(
              'div',
              { style: { padding: "1em", height: "100%", overflow: "auto", flexWrap: "wrap", display: "block", justifyContent: "space-around" } },
              this.state.info.files.map(function (file, i) {

                var fileUrl = self.getUrlForFile(file);

                var wrapperStyle = { padding: "0.5em 1em", cursor: 'pointer', display: "flex", alignItems: "center", justifyContent: 'space-between', background: "rgba(0,0,0,.1)", marginBottom: "1px" };

                return React.createElement(
                  'div',
                  { key: i, onClick: function onClick(e) {
                      self.downloadFile(file);
                    }, style: wrapperStyle, 'aria-label': self.t('Download') + ' ' + file.filename },
                  React.createElement(
                    'span',
                    { style: { marginLeft: "1em", wordBreak: "break-all" } },
                    file.filename
                  ),
                  ' ',
                  React.createElement(
                    'span',
                    { style: { opacity: 0.8 } },
                    self.getHumanFilesize(file)
                  )
                );
              })
            )
          ) : false
        )
      )
    );
  }

});